@@ -20,7 +20,7 @@ use Config::Any;
 use File::HomeDir;
 
 use overload (
-    '@{}'  => \&get_files,
+    '@{}'  => sub { $_[0]->files },
     'bool' => sub { 1 },
 );
 
@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
     as_is => [qw/get_options/],
 );
 
-our $VERSION = version->new('0.3.0');
+our $VERSION = version->new('0.3.1');
 our $EXIT    = 1;
 
 has options => (
@@ -238,34 +238,39 @@ sub process {
     while (my $arg = shift @args) {
         my $action = '';
         try {
-                my ($long, $short, $arg_data);
-                if ( $arg =~ /^-- (\w[^=\s]+) (?:= (.*) )?/xms ) {
-                    $long = $1;
-                    $arg_data = $2;
-                }
-                elsif ( $arg =~ /^- (\w) =? (.*)/xms ) {
-                    $short = $1;
-                    $arg_data  = $2;
-                }
-                else {
-                    push @{ $self->files }, $arg;
-                    die $self->sub_command ? "last\n" : "next\n";
-                }
+            my ($long, $short, $arg_data);
+            if ( $arg =~ /^-- (\w[^=\s]+) (?:= (.*) )?/xms ) {
+                $long = $1;
+                $arg_data = $2;
+            }
+            elsif ( $arg =~ /^- (\w) =? (.*)/xms ) {
+                $short = $1;
+                $arg_data  = $2;
+            }
+            else {
+                push @{ $self->files }, $arg;
+                die $self->sub_command ? "last\n" : "next\n";
+            }
 
-                my $opt = $self->best_option( $long, $short );
-                $opt->value( $self->opt->{ $opt->name } );
+            my ($opt, $new_value) = $self->best_option( $long, $short );
+            if (defined $new_value) {
+                $long = $opt->name;
+                $short = undef;
+                ($arg_data) = $arg =~ /^--?(\d+)$/;
+            }
+            $opt->value( $self->opt->{ $opt->name } );
 
-                my ($value, $used) = $opt->process( $long, $short, $arg_data, \@args );
-                my $opt_name = $opt->name;
-                if ( $self->opt->auto_complete && $opt_name eq 'auto_complete_list' ) {
-                    print join ' ', $self->list_options;
-                    exit 0;
-                }
-                $self->opt->{$opt->name} = $value;
+            my ($value, $used) = $opt->process( $long, $short, $arg_data, \@args );
+            my $opt_name = $opt->name;
+            if ( $self->opt->auto_complete && $opt_name eq 'auto_complete_list' ) {
+                print join ' ', $self->list_options;
+                exit 0;
+            }
+            $self->opt->{$opt->name} = $value;
 
-                if ( !$used && $short && defined $arg_data && length $arg_data ) {
-                    unshift @args, '-' . $arg_data;
-                }
+            if ( !$used && $short && defined $arg_data && length $arg_data ) {
+                unshift @args, '-' . $arg_data;
+            }
         }
         catch {
             if ( $_ eq "next\n" ) {
@@ -393,11 +398,19 @@ sub best_option {
     for my $name ( $meta->get_attribute_list ) {
         my $opt = $meta->get_attribute($name);
 
-        return $opt if $long && $opt->name eq $long;
+        return ($opt, undef) if $long && $opt->name eq $long;
 
         for my $name (@{ $opt->names }) {
-            return $opt if $long && $name eq $long;
-            return $opt if $short && $name eq $short;
+            return ($opt, undef) if defined $long && $name eq $long;
+            return ($opt, undef) if defined $short && $name eq $short;
+        }
+    }
+
+    if (($long && $long =~ /^\d+$/xms) || (defined $short && $short =~ /^\d$/xms)) {
+        $meta = $self->opt->meta;
+        for my $name ( $meta->get_attribute_list ) {
+            my $opt = $meta->get_attribute($name);
+            return ($opt, $long || $short) if $opt->number;
         }
     }
 
@@ -407,23 +420,17 @@ sub best_option {
         die [ Getopt::Alt::Exception->new(
                 message => "Unknown option '" . ($long ? "--$long" : "-$short") . "'\n",
                 option  => ($long ? "--$long" : "-$short"),
-            ) ]
+            ) ];
     }
     else {
         die [ Getopt::Alt::Exception->new(
                 help    => 1,
                 message => "Unknown option '" . ($long ? "--$long" : "-$short") . "'\n",
                 option  => ($long ? "--$long" : "-$short"),
-            ) ]
+            ) ];
     }
 }
 
-sub get_files {
-    my ($self) = @_;
-
-    return $self->files;
-}
-
 sub _show_help {
     my ($self, $verbosity, $msg) = @_;
 
@@ -461,7 +468,7 @@ Getopt::Alt - Command line option passing with with lots of features
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt version 0.3.0.
+This documentation refers to Getopt::Alt version 0.3.1.
 
 =head1 SYNOPSIS
 
@@ -492,6 +499,7 @@ This documentation refers to Getopt::Alt version 0.3.0.
        'increment|c+',
        'nullable|n=s?',
        'negatable|b!',
+       'fixed_values|fixed-values|f=[a|bunch|of|fixed|values]',
    );
    print Dumper $options->opt;           # passed parameters
    print join ',', @{ $options->files }; # non option parameters
@@ -506,6 +514,7 @@ This documentation refers to Getopt::Alt version 0.3.0.
        'increment|c+',
        'nullable|n=s?',
        'negatable|b!',
+       'fixed_values|fixed-values|f=[a|bunch|of|fixed|values]',
    );
 
    # with configuration
@@ -522,6 +531,7 @@ This documentation refers to Getopt::Alt version 0.3.0.
            'increment|c+',
            'nullable|n=s?',
            'negatable|b!',
+           'fixed_values|fixed-values|f=[a|bunch|of|fixed|values]',
        ],
    );
    print $cmd;   # sub command
@@ -543,6 +553,7 @@ This documentation refers to Getopt::Alt version 0.3.0.
            'increment|c+',
            'nullable|n=s?',
            'negatable|b!',
+           'fixed_values|fixed-values|f=[a|bunch|of|fixed|values]',
        ],
    );
    print Dumper $option->opt;  # command with sub command options merged in
@@ -740,9 +751,6 @@ Returns a list of all command line options in the current object.
 
 =head3 C<best_option ()>
 
-=head3 C<get_files ()>
-
-
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
