@@ -20,7 +20,7 @@ Moose::Exporter->setup_import_methods(
 );
 
 
-our $VERSION = version->new('0.3.0');
+our $VERSION = version->new('0.3.1');
 
 Moose::Util::meta_attribute_alias('Getopt::Alt::Option');
 
@@ -42,6 +42,10 @@ has increment => (
     is  => 'rw',
     isa => 'Bool',
 );
+has number => (
+    is  => 'rw',
+    isa => 'Bool',
+);
 has negatable => (
     is  => 'rw',
     isa => 'Bool',
@@ -71,17 +75,25 @@ has value => (
     isa       => 'Any',
     predicate => 'has_value',
 );
+has values => (
+    is        => 'rw',
+    isa       => 'ArrayRef',
+    predicate => 'has_values',
+);
 
 my $r_name     = qr/ [^|\s=+!?@%-][^|\s=+!?@%]* /xms;
 my $r_alt_name = qr/ $r_name | \\d /xms;
 my $r_names    = qr/ $r_name (?: [|] $r_alt_name)* /xms;
 my $r_type     = qr/ [nifsd] /xms;
 my $r_ref      = qr/ [%@] /xms;
-my $r_type_ref = qr/ = $r_type $r_ref? /xms;
+my $r_sub_val  = qr/ [\w-]+ /xms;
+my $r_values   = qr/ \[ $r_sub_val (?: [|] $r_sub_val )* \] /xms;
+my $r_type_ref = qr/ = (?: $r_type $r_ref? | $r_values ) /xms;
 my $r_inc      = qr/ [+] /xms;
+my $r_number   = qr/ [+][+] /xms;
 my $r_neg      = qr/ [!] /xms;
 my $r_null     = qr/ [?] /xms;
-my $r_spec     = qr/^ ( $r_names ) ( $r_inc | $r_neg | $r_type_ref )? ( $r_null )? $/xms;
+my $r_spec     = qr/^ ( $r_names ) ( $r_inc | $r_number | $r_neg | $r_type_ref )? ( $r_null )? $/xms;
 
 # calling new => ->new( 'test|t' )
 #                ->new( name => 'text', names => [qw/test tes te t/], ... )
@@ -119,6 +131,11 @@ sub build_option {
             if ($option eq '=') {
                 ($type, $extra) = split /;/xms, $options;
             }
+            elsif ($options eq '++') {
+                push @params, 'increment' => 1;
+                push @params, 'number'    => 1;
+                push @params, 'type'      => 'Int';
+            }
             elsif ($option eq '+') {
                 push @params, 'increment' => 1;
             }
@@ -134,10 +151,16 @@ sub build_option {
                 if ( length $type == 1 ) {
                     ($text) = $type =~ /^ ($r_type) $/xms;
                 }
-                else {
+                elsif ( length $type == 2 ) {
                     ($text, $ref) = $type =~ /^ ($r_type) ($r_ref) $/xms;
                     push @params, ref => $ref eq '%' ? 'HashRef' : 'ArrayRef';
                 }
+                else {
+                    $type =~ s/(?: ^\[ | \]$ )//gxms;
+                    my @values = split /[|]/, $type;
+                    $text = 's';
+                    push @params, values => \@values;
+                }
 
                 push @params,
                     type =>
@@ -210,25 +233,33 @@ sub process {
             : $self->type eq 'Str' && length $arg_data > 0                                  ? $arg_data
             :                                                                                 confess "The value '$arg_data' is not of type '".$self->type."'\n";
 
+        if ($self->values && !grep { $value eq $_ } @{ $self->values }) {
+            die [ Getopt::Alt::Exception->new(
+                    message => "The option '$name' must be one of " . ( join ', ', @{ $self->values } ) . "\n",
+                    option  => $name,
+                    type    => $self->type
+                ) ]
+        }
+
         if ($self->ref) {
             my $old;
             if ($self->ref eq 'ArrayRef') {
                 $old = $self->value || [];
                 push @$old, $value;
             }
-            elsif ($self->ref eq 'HashRef') {
+            else {
                 $old = $self->value || {};
                 $old->{$key} = $value;
             }
-            else {
-                confess "Unknown reference type '" . $self->ref . "' (from " . $self->opt . ")\n";
-            }
             $value = $old;
         }
     }
     elsif ($self->increment) {
         $value = ($self->value || 0) + 1;
     }
+    elsif ($self->number) {
+        $value = $long || $short
+    }
     elsif ($self->negatable) {
         $value = $long && $long =~ /^no-/xms ? 0 : 1;
     }
@@ -251,7 +282,7 @@ Getopt::Alt::Option - Sets up a particular command line option
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt::Option version 0.3.0.
+This documentation refers to Getopt::Alt::Option version 0.3.1.
 
 =head1 SYNOPSIS
 
